@@ -81,6 +81,7 @@ typedef enum {
 /**
  * Set the geometry validation mode
  * @ingroup capi
+ * @note obsolete
  */
 SFCGAL_API void                      sfcgal_set_geometry_validation( int enabled );
 
@@ -96,6 +97,16 @@ SFCGAL_API sfcgal_geometry_type_t    sfcgal_geometry_type_id( const sfcgal_geome
  */
 SFCGAL_API int                       sfcgal_geometry_is_valid( const sfcgal_geometry_t* );
 
+/**
+ * Tests if the given geometry is valid or not
+ * And return details in case of invalidity
+ * @param geom the input geometry
+ * @param invalidity_reason input/output parameter. If non null, a null-terminated string could be allocated and contain reason of the invalidity
+ * @param invalidity_location input/output parameter. If non null, a geometry could be allocated and contain the location of the invalidity
+ * @ingroup capi
+ */
+SFCGAL_API int                       sfcgal_geometry_is_valid_detail( const sfcgal_geometry_t* geom, char** invalidity_reason, sfcgal_geometry_t** invalidity_location );
+
 /**
  * Tests if the given geometry is 3D or not
  * @ingroup capi
@@ -463,6 +474,17 @@ SFCGAL_API const sfcgal_geometry_t*  sfcgal_solid_shell_n( const sfcgal_geometry
 SFCGAL_API void                      sfcgal_solid_add_shell( sfcgal_geometry_t* solid, sfcgal_geometry_t* shell );
 
 
+/**
+ * Gets the validity flag of the geometry.
+ */
+int sfcgal_geometry_has_validity_flag( const sfcgal_geometry_t* geom );
+
+/**
+ * Sets the validity flag of the geometry.
+ * FIXME We better have geometry constructors to directly build valid geometries
+ */
+void sfcgal_geometry_force_valid( sfcgal_geometry_t* geom, int valid );
+
 /*--------------------------------------------------------------------------------------*
  *
  * Support for SFCGAL::PreparedGeometry
@@ -782,6 +804,14 @@ SFCGAL_API sfcgal_geometry_t*          sfcgal_geometry_offset_polygon( const sfc
  */
 SFCGAL_API sfcgal_geometry_t*          sfcgal_geometry_straight_skeleton( const sfcgal_geometry_t* geom );
 
+/**
+ * Returns the straight skeleton of the given Geometry with the distance to the border as M coordinate
+ * @pre isValid(geom) == true
+ * @post isValid(return) == true
+ * @ingroup capi
+ */
+SFCGAL_API sfcgal_geometry_t*          sfcgal_geometry_straight_skeleton_distance_in_m( const sfcgal_geometry_t* geom );
+
 /**
  * Returns the approximate medial axis for the given Polygon
  * Approximate medial axis is based on straight skeleton
